==> nessus-core_0.99.4.orig.tar.gz: nessus-core/nessus/sighand.c <==
/* Nessus
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Signals handler
 */

#include <includes.h>
#include "nsr_output.h"
#include "error_dialog.h"
#include "globals.h"

extern struct arglist * Hosts;

void 
sighand_pipe()
{
#ifdef USE_GTK
  if(!F_quiet_mode)
   show_error_and_wait("Connection closed by the server (SIGPIPE caught)");
  else
#else
  fprintf(stderr, "Connection closed by the server (SIGPIPE caught)\n");
#endif  
  shutdown(0,2);
  closesocket(0);
  _exit(1);   
}


void 
sighand_sigsegv()
{
 signal(SIGSEGV, exit);
 fprintf(stderr, "ERROR ! SIGSEGV Caught !\n");
 if(Hosts)
 {
  arglist_to_file(Hosts, "nessus_test_dump.nsr");
  fprintf(stderr, "Current test saved as 'nessus_test_dump.nsr'\n");
 }
 exit(1);
}

void 
sighand_alarm()
{
#ifdef USE_GTK
  if(!F_quiet_mode)show_error_and_wait("Connection timed out");
  else
#else  
 fprintf(stderr, "Connection timed out\n");
#endif  
  shutdown(0,2);
  closesocket(0);
  _exit(1);
}

==> nessus-core-1.0.5.tar.gz: nessus-core/nessus/sighand.c <==
/* Nessus
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Signals handler
 */

#include <includes.h>
#include "nsr_output.h"
#include "error_dialog.h"
#include "globals.h"


void 
sighand_pipe()
{
#ifdef USE_GTK
  if(!F_quiet_mode)
   show_error_and_wait("Connection closed by the server (SIGPIPE caught)");
  else
#else
  fprintf(stderr, "Connection closed by the server (SIGPIPE caught)\n");
#endif  
  shutdown(0,2);
  closesocket(0);
  _exit(1);   
}


void 
sighand_alarm()
{
#ifdef USE_GTK
  if(!F_quiet_mode)show_error_and_wait("Connection timed out");
  else
#else  
 fprintf(stderr, "Connection timed out\n");
#endif  
  shutdown(0,2);
  closesocket(0);
  _exit(1);
}
 
void sighand_exit()
{
 if(GlobalSocket > 0)
 {
   network_printf( "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
   shutdown(GlobalSocket, 2);
   close(GlobalSocket);
   GlobalSocket = -1;
 }
 exit (1);
}
